@@ -206,7 +206,7 @@ bool KCamera::test()
 {
     // TODO: Make testing non-blocking (maybe via KIO?)
     // Currently, a failed serial test times out at about 30 sec.
-    return camera() != 0;
+    return camera() != nullptr;
 }
 
 void KCamera::load(KConfig *config)
@@ -230,7 +230,7 @@ void KCamera::save(KConfig *config)
 
 QString KCamera::portName()
 {
-    QString port = m_path.left(m_path.indexOf(":")).toLower();
+    const QString port = m_path.left(m_path.indexOf(QLatin1Char(':'))).toLower();
     if (port == "serial") return i18n("Serial");
     if (port == "usb") return i18n("USB");
     return i18n("Unknown port");
@@ -278,15 +278,15 @@ QStringList KCamera::supportedPorts()
     initInformation();
     QStringList ports;
     if (m_abilities.port & GP_PORT_SERIAL) {
-        ports.append("serial");
+        ports.append(QLatin1String("serial"));
     }
     if (m_abilities.port & GP_PORT_USB) {
-        ports.append("usb");
+        ports.append(QLatin1String("usb"));
     }
     return ports;
 }
 
-CameraAbilities KCamera::abilities()
+CameraAbilities KCamera::abilities() const
 {
     return m_abilities;
 }
@@ -300,10 +300,11 @@ KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *dev
 
     setModal( true );
     m_device = device;
-    connect(m_device, SIGNAL(error(QString)),
-        SLOT(slot_error(QString)));
-    connect(m_device, SIGNAL(error(QString,QString)),
-        SLOT(slot_error(QString,QString)));
+    connect(m_device, qOverload<const QString&>(&KCamera::error),
+		this, qOverload<const QString&>(&KameraDeviceSelectDialog::slot_error));
+
+    connect(m_device, qOverload<const QString&, const QString&>(&KCamera::error),
+		this, qOverload<const QString&, const QString&>(&KameraDeviceSelectDialog::slot_error));
 
     QWidget *page = new QWidget( this );
 
@@ -320,10 +321,9 @@ KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *dev
     m_modelSel->setModel(m_model);
 
     topLayout->addWidget( m_modelSel );
-    connect(m_modelSel, SIGNAL(activated(QModelIndex)),
-        SLOT(slot_setModel(QModelIndex)));
-    connect(m_modelSel, SIGNAL(clicked(QModelIndex)),
-        SLOT(slot_setModel(QModelIndex)));
+    connect(m_modelSel, &QListView::activated, this, &KameraDeviceSelectDialog::slot_setModel);
+    connect(m_modelSel, &QListView::clicked, this, &KameraDeviceSelectDialog::slot_setModel);
+
     // make sure listview only as wide as it needs to be
     m_modelSel->setSizePolicy(QSizePolicy(QSizePolicy::Maximum,
         QSizePolicy::Preferred));
@@ -362,10 +362,9 @@ KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *dev
 
     lay->addWidget(grid2);
     lay->addWidget( m_settingsStack );
-    connect(m_serialRB, SIGNAL(toggled(bool)),
-                this, SLOT(changeCurrentIndex()) );
-    connect(m_USBRB, SIGNAL(toggled(bool)),
-                this, SLOT(changeCurrentIndex()) );
+    connect(m_serialRB, &QRadioButton::toggled, this, &KameraDeviceSelectDialog::changeCurrentIndex);
+    connect(m_USBRB, &QRadioButton::toggled, this, &KameraDeviceSelectDialog::changeCurrentIndex);
+
     // none tab
     m_settingsStack->insertWidget(INDEX_NONE,
             new QLabel(i18n("No port type selected."),
@@ -400,8 +399,8 @@ KameraDeviceSelectDialog::KameraDeviceSelectDialog(QWidget *parent, KCamera *dev
     // to enableButtonOk(true) in slot_setModel.
     okButton->setEnabled(false);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    connect(okButton, SIGNAL(clicked(bool)), SLOT(accept()));
-    connect(cancelButton, SIGNAL(clicked(bool)), SLOT(close()));
+    connect(okButton, &QPushButton::clicked, this, &KameraDeviceSelectDialog::accept);
+    connect(cancelButton, &QPushButton::clicked, this, &KameraDeviceSelectDialog::close);
     rightLayout->addWidget(m_OkCancelButtonBox);
 
     // query gphoto2 for existing serial ports
@@ -492,10 +491,13 @@ void KameraDeviceSelectDialog::save()
 void KameraDeviceSelectDialog::load()
 {
     QString path = m_device->path();
-    QString port = path.left(path.indexOf(':')).toLower();
+    QString port = path.left(path.indexOf(QLatin1Char(':'))).toLower();
 
-    if (port == "serial") setPortType(INDEX_SERIAL);
-    if (port == "usb") setPortType(INDEX_USB);
+    if (port == QLatin1String("serial")) {
+        setPortType(INDEX_SERIAL);
+    } else if (port == QLatin1String("usb")) {
+        setPortType(INDEX_USB);
+    }
 
     QList<QStandardItem *> items = m_model->findItems(m_device->model());
     foreach (QStandardItem *item, items) {
