@@ -441,11 +441,11 @@ void KameraProtocol::statRoot(void)
 {
     KIO::UDSEntry entry;
 
-    entry.insert( KIO::UDSEntry::UDS_NAME, QString::fromLocal8Bit("/"));
+    entry.fastInsert( KIO::UDSEntry::UDS_NAME, QString::fromLocal8Bit("/"));
 
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
+    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
 
-    entry.insert(KIO::UDSEntry::UDS_ACCESS,(S_IRUSR | S_IRGRP | S_IROTH));
+    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS,(S_IRUSR | S_IRGRP | S_IROTH));
     statEntry(entry);
     finished();
     // If we just do this call, timeout right away if no other requests are
@@ -460,23 +460,23 @@ void KameraProtocol::split_url2camerapath(QString url,
     QStringList	components, camarr;
     QString		cam, camera, port;
 
-    components	= url.split('/', QString::SkipEmptyParts);
+    components	= url.split(QLatin1Char('/'), QString::SkipEmptyParts);
     if (components.size() == 0) {
         return;
     }
     cam	= path_unquote(components.takeFirst());
     if (!cam.isEmpty()) {
-        camarr  = cam.split('@');
+        camarr  = cam.split(QLatin1Char('@'));
         camera  = path_unquote(camarr.takeFirst());
         port    = path_unquote(camarr.takeLast());
         setCamera (camera, port);
     }
-    if (components.size() == 0)  {
+    if (components.isEmpty())  {
         directory = "/";
         return;
     }
     file		= path_unquote(components.takeLast());
-    directory 	= path_unquote("/"+components.join("/"));
+    directory 	= path_unquote("/"+components.join(QLatin1Char('/')));
 }
 
 // Implements a regular stat() of a file / directory, returning all we know about it
@@ -516,11 +516,11 @@ void KameraProtocol::statRegular(const QUrl &xurl)
         GPHOTO_TEXT_FILE(summary);
 #undef GPHOTO_TEXT_FILE
 
-        QString xname = current_camera + '@' + current_port;
-        entry.insert( KIO::UDSEntry::UDS_NAME, path_quote(xname));
-        entry.insert( KIO::UDSEntry::UDS_DISPLAY_NAME, current_camera);
-        entry.insert( KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
-        entry.insert( KIO::UDSEntry::UDS_ACCESS,(S_IRUSR | S_IRGRP | S_IROTH));
+        QString xname = current_camera + QLatin1Char('@') + current_port;
+        entry.fastInsert( KIO::UDSEntry::UDS_NAME, path_quote(xname));
+        entry.fastInsert( KIO::UDSEntry::UDS_DISPLAY_NAME, current_camera);
+        entry.fastInsert( KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
+        entry.fastInsert( KIO::UDSEntry::UDS_ACCESS,(S_IRUSR | S_IRGRP | S_IROTH));
         statEntry(entry);
         finished();
         return;
@@ -627,18 +627,18 @@ void KameraProtocol::listDir(const QUrl &yurl)
     split_url2camerapath(yurl.path(), directory, file);
 
     if (!file.isEmpty()) {
-        if (directory == "/") {
-            directory = '/' + file;
+        if (directory == QLatin1Char('/')) {
+            directory = QLatin1Char('/') + file;
         } else {
-            directory = directory + '/' + file;
+            directory = directory + QLatin1Char('/') + file;
         }
     }
 
-    if (yurl.path() == "/") {
+    if (yurl.path() == QLatin1Char('/')) {
         QUrl xurl;
         // List the available cameras
         QStringList groupList = m_config->groupList();
-        qCDebug(KAMERA_KIOSLAVE) << "Found cameras: " << groupList.join(", ");
+        qCDebug(KAMERA_KIOSLAVE) << "Found cameras: " << groupList.join(QStringLiteral(", "));
         QStringList::Iterator it;
         KIO::UDSEntry entry;
 
@@ -712,7 +712,7 @@ void KameraProtocol::listDir(const QUrl &yurl)
             m_cfgPath = cg.readEntry("Path");
 
             // we autodetected those ...
-            if (m_cfgPath.contains(QString("usb:"))) {
+            if (m_cfgPath.contains(QLatin1String("usb:"))) {
                 cg.deleteGroup();
                 continue;
             }
@@ -720,13 +720,13 @@ void KameraProtocol::listDir(const QUrl &yurl)
             QString xname;
 
             entry.clear();
-            entry.insert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
-            entry.insert(KIO::UDSEntry::UDS_ACCESS,
+            entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
+            entry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
                     (S_IRUSR | S_IRGRP | S_IROTH |S_IWUSR | S_IWGRP | S_IWOTH));
             xname = (*it)+'@'+m_cfgPath;
-            entry.insert(KIO::UDSEntry::UDS_NAME,path_quote(xname));
+            entry.fastInsert(KIO::UDSEntry::UDS_NAME,path_quote(xname));
             // do not confuse regular users with the @usb...
-            entry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME,*it);
+            entry.fastInsert(KIO::UDSEntry::UDS_DISPLAY_NAME,*it);
             listEntry(entry);
         }
 
@@ -734,13 +734,13 @@ void KameraProtocol::listDir(const QUrl &yurl)
 
         for (portsit = ports.begin(); portsit != ports.end(); portsit++) {
             entry.clear();
-            entry.insert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
+            entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
             // do not confuse regular users with the @usb...
-            entry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME,portsit.value());
-            entry.insert(KIO::UDSEntry::UDS_NAME,
-                    path_quote(portsit.value()+'@'+portsit.key()));
+            entry.fastInsert(KIO::UDSEntry::UDS_DISPLAY_NAME,portsit.value());
+            entry.fastInsert(KIO::UDSEntry::UDS_NAME,
+                    path_quote(portsit.value()+QLatin1Char('@')+portsit.key()));
 
-            entry.insert(KIO::UDSEntry::UDS_ACCESS,
+            entry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
                     (S_IRUSR | S_IRGRP | S_IROTH |S_IWUSR | S_IWGRP | S_IWOTH));
             listEntry(entry);
         }
@@ -753,7 +753,7 @@ void KameraProtocol::listDir(const QUrl &yurl)
 
         qCDebug(KAMERA_KIOSLAVE) << "redirecting to /";
         if (!current_camera.isEmpty() && !current_port.isEmpty()) {
-            rooturl.setPath('/'+current_camera+'@'+current_port+'/');
+            rooturl.setPath(QLatin1Char('/')+current_camera+QLatin1Char('@')+current_port+QLatin1Char('/'));
         } else {
             rooturl.setPath("/");
         }
@@ -967,49 +967,49 @@ void KameraProtocol::translateTextToUDS(KIO::UDSEntry &udsEntry,
     const char *text)
 {
     udsEntry.clear();
-    udsEntry.insert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFREG);
-    udsEntry.insert(KIO::UDSEntry::UDS_NAME,path_quote(fn));
-    udsEntry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME,fn);
-    udsEntry.insert(KIO::UDSEntry::UDS_SIZE,strlen(text));
-    udsEntry.insert(KIO::UDSEntry::UDS_ACCESS,(S_IRUSR | S_IRGRP | S_IROTH));
-    udsEntry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString("text/plain"));
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFREG);
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_NAME,path_quote(fn));
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_DISPLAY_NAME,fn);
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_SIZE,strlen(text));
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_ACCESS,(S_IRUSR | S_IRGRP | S_IROTH));
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QString("text/plain"));
 }
 
 // translate a CameraFileInfo to a UDSFieldType
 // which we can return as a directory listing entry
 void KameraProtocol::translateFileToUDS(KIO::UDSEntry &udsEntry,
                                         const CameraFileInfo &info,
-                                        QString name)
+                                        const QString &name)
 {
 
     udsEntry.clear();
 
-    udsEntry.insert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFREG);
-    udsEntry.insert(KIO::UDSEntry::UDS_NAME,path_quote(name));
-    udsEntry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME,name);
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFREG);
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_NAME,path_quote(name));
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_DISPLAY_NAME,name);
 
     if (info.file.fields & GP_FILE_INFO_SIZE) {
-        udsEntry.insert(KIO::UDSEntry::UDS_SIZE,info.file.size);
+        udsEntry.fastInsert(KIO::UDSEntry::UDS_SIZE,info.file.size);
     }
 
     if (info.file.fields & GP_FILE_INFO_MTIME) {
-        udsEntry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME,info.file.mtime);
+        udsEntry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME,info.file.mtime);
     } else {
-        udsEntry.insert(KIO::UDSEntry::UDS_MODIFICATION_TIME,time(NULL));
+        udsEntry.fastInsert(KIO::UDSEntry::UDS_MODIFICATION_TIME,time(NULL));
     }
 
     if (info.file.fields & GP_FILE_INFO_TYPE) {
-        udsEntry.insert(KIO::UDSEntry::UDS_MIME_TYPE,
+        udsEntry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE,
                         QString::fromLatin1(info.file.type));
     }
 
     if (info.file.fields & GP_FILE_INFO_PERMISSIONS) {
-        udsEntry.insert(KIO::UDSEntry::UDS_ACCESS,
+        udsEntry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
                         ((info.file.permissions & GP_FILE_PERM_READ) ?
                              (S_IRUSR | S_IRGRP | S_IROTH) : 0)
                         );
     } else {
-        udsEntry.insert(KIO::UDSEntry::UDS_ACCESS,S_IRUSR | S_IRGRP | S_IROTH);
+        udsEntry.fastInsert(KIO::UDSEntry::UDS_ACCESS,S_IRUSR | S_IRGRP | S_IROTH);
     }
 
     // TODO: We do not handle info.preview in any way
@@ -1023,13 +1023,13 @@ void KameraProtocol::translateDirectoryToUDS(KIO::UDSEntry &udsEntry,
 
     udsEntry.clear();
 
-    udsEntry.insert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
-    udsEntry.insert(KIO::UDSEntry::UDS_NAME,path_quote(dirname));
-    udsEntry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, dirname);
-    udsEntry.insert(KIO::UDSEntry::UDS_ACCESS,
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE,S_IFDIR);
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_NAME,path_quote(dirname));
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_DISPLAY_NAME, dirname);
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_ACCESS,
             S_IRUSR | S_IRGRP | S_IROTH |S_IWUSR | S_IWGRP |
             S_IWOTH | S_IXUSR | S_IXOTH | S_IXGRP);
-    udsEntry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QString("inode/directory"));
+    udsEntry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QString("inode/directory"));
 }
 
 bool KameraProtocol::cameraSupportsDel(void)
